@@ -62,7 +62,7 @@ GOOD_WORDS = ['back', 'bad', 'badge', 'bag', 'ball', 'bar', 'bare', 'base', 'bas
                  'whole', 'wick', 'wide', 'wife', 'win', 'wine', 'wing', 'wise', 'wish', 'woke', 'womb', 'wood', 'word', 'wore', 'work',
                  'worse', 'wreck', 'wright', 'write', 'wrong', 'wrote', 'wrought', 'year', 'yell', 'young', 'youth', 'zip']
     #Remove: pull, full, bull, real
-VOWELS = ['aa','ae','eh','ey','ih','iy','ow','uh','uw']
+MONOPHTHONGS = ['aa','ae','eh','ey','ih','iy','ow','uh','uw']
 
 class WTManager(BulkManager):
     tbl_name = "buckeyebrowser_wordtoken"
@@ -134,6 +134,7 @@ Group by StressVowel) AS averages""",[self.pk])
         words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker').filter(Dialog__Speaker=self)
         words = words.filter(WordType__CVSkel='CVC')
         words = words.filter(WordType__Label__in = GOOD_WORDS)
+        words = words.filter(WordType__StressVowel__in = MONOPHTHONGS)
         allout = []
         print(str(self))
         print("\n")
